@@ -1,4 +1,4 @@
-from pathlib import Path
+from networktools.path import home_path
 import asyncio
 import functools
 from asyncio import shield, wait_for
@@ -11,43 +11,32 @@ from data_amqp import AMQPData
 
 from networktools.library import my_random_string, check_gsof
 from networktools.colorprint import gprint, bprint, rprint
-from networktools.library import (pattern_value, fill_pattern, context_split,
-                                  gns_loads, gns_dumps)
-from networktools.geo import (radius, rad2deg, deg2rad,
-                              ecef2llh, llh2ecef, get_from_ecef, ecef2neu)
+from networktools.geo import (radius, deg2rad,
+                              ecef2llh, llh2ecef)
 from networktools.time import get_datetime_di
 from networktools.library import geojson2json
-from networktools.time import get_datetime_di
 
 # log module
 from basic_logtools.filelog import LogFile as FileLog
 
 # TaskTools for concurrency loop
-from tasktools.taskloop import coromask, renew, simple_fargs, simple_fargs_out
+from tasktools.taskloop import coromask, renew, simple_fargs_out
 from tasktools.scheduler import TaskScheduler
 
 # Async Socket
 # from gnsocket.gn_socket import GNCSocket
 
-# Datetime
-from datetime import tzinfo, timedelta, datetime
 
 # Maths
-import numpy as np
 import time
 import ujson as json
 from multiprocessing import Lock
 
-# from datawork
-from .geo2rdb import geojson2rethinkjson
-
 
 # RethinkDB module
 from rethinkdb import RethinkDB
 rdb = RethinkDB()
 rdb.set_loop_type('asyncio')
-from networktools.path import home_path
-from basic_logtools.filelog import LogFile
 
 
 def qjson(x): return json.loads(json.dumps(x))
@@ -119,16 +108,15 @@ class DragonGather(TaskScheduler):
         }
         self.set_new_run_task(**coros_callback_dict)
         self.log_path = home_path(kwargs.get('log_path', '~/log'))
-        log_level = kwargs.get('log_level', 'INFO')
 
     @property
     def class_name(self):
         return self.__class__.__name__
 
-
     def set_isg(self, uin=4):
         """
-        Defines a new id for task related to collect data insice a worker, check if exists
+        Defines a new id for task related to collect data insice a worker,
+        check if exists
         """
         isg = my_random_string(uin)
         while True:
@@ -192,7 +180,6 @@ class DragonGather(TaskScheduler):
         q2client = self.queue2client
         wq = self.queue_client_n2t
         rq = self.queue_client_t2n
-        process = dict()
         await asyncio.sleep(.5)
         try:
             # first read the msgs from system and send to client
@@ -209,7 +196,6 @@ class DragonGather(TaskScheduler):
             if not rq.empty():
                 for i in range(rq.qsize()):
                     msg = rq.get()
-                    idc = msg.get('idc')
                     result = await self.client_interpreter(msg)
                     rprint("Resultado recibido de client:%s" % result)
                     """
@@ -228,39 +214,31 @@ class DragonGather(TaskScheduler):
         self.lock = Lock()
         result = []
         msg = msg_in.get('dt').get('msg')
+        print("Msg recv")
         if isinstance(msg, dict):
             command = msg.get('command').get('action')
             answer = msg.get('command').get('answer')
-            result = None
-            """
-            if command == 'init_gui':
-                # if self.gui_group empty:
-                if not self.gui_group:
-                    with self.lock:
-                        self.sc.value = not self.sc.value
-                # add group and id
-                idg = args[0]
-                group = args[1]
-                # relationship between a gui and a group of stations
-                self.gui_group.update({idg: group})
-            """
-            if command in self.msg_process:
-                if answer:
-                    varname = msg.get('command').get('varname')
-                    def print_dict(x): return [print(
-                        "%s->%s" % (k, v) for k, v in x.items())]
-                    msg_process = self.msg_process.get(
-                        command, {}).get(varname, print_dict)
-                    result = msg_process(answer)
+            result = {}
+            gprint("*"*20)
+            bprint(answer.keys())
+            gprint("*"*20)
+            if command in self.msg_process and answer:
+                rprint("Creating...")
+                varname = msg.get('command').get('varname')
+                def print_dict(x): return [print(
+                    "%s->%s" % (k, v) for k, v in x.items())]
+                msg_process = self.msg_process.get(
+                    command, {}).get(varname, print_dict)
+                bprint("msg process _> %s" % msg_process)
+                result = msg_process(answer)
+                rprint(f"Result from process list {result}")
         return result
 
     async def check_status(self, *args, **kwargs):
         wq = self.queue_list[0]
         rq = self.queue_list[1]
-        process = dict()
         await asyncio.sleep(.5)
         try:
-            msg_from_source = []
             if not rq.empty():
                 for i in range(rq.qsize()):
                     msg = rq.get()
@@ -339,24 +317,6 @@ class DragonGather(TaskScheduler):
     def add_process_queue(self, process_queue):
         self.process_queue = process_queue
 
-    async def recv_msg(self, loop, idc):
-        ans = []
-        msg = ''
-        while not msg == '<END>':
-            msg = await gs.recv_msg(idc)
-            if msg != '<END>' and msg is not None:
-                ans.append(msg)
-            if msg == '<END>':
-                break
-        return ans
-
-    async def receive_wc(self, idc):
-        loop = asyncio.get_event_loop()
-        msg = await self.recv_msg(loop, idc)
-        for m in msg:
-            print(m)
-        return msg
-
     def load_stations(self, msg):
         qs = msg
         POSITION = dict()
@@ -395,18 +355,18 @@ class DragonGather(TaskScheduler):
             if 'code' in qs:
                 self.common[qs][ids] = dict()
             dataset = self.stations.get(ids)
-            code = dataset.get('code')
+            # code = dataset.get('code')
             self.process_queue.put(ids)
             self.enqueued.append(ids)
             self.gui_set.append(dataset['code'])
 
     def load_dbdata(self, msg):
-        qs = dict()
-        for m in msg:
-            print(m)
-            qs = json.loads(m)
-        for k in qs:
-            self.db_data[k] = qs[k]
+        bprint("="*10)
+        gprint(msg)
+        print(len(msg), type(msg))
+        rprint("="*10)
+        for k, v in msg.items():
+            self.db_data[k] = v
 
     def msg_load_stations(self):
         get_lst = {'user': 'admin',
@@ -450,7 +410,6 @@ class DragonGather(TaskScheduler):
         DragonDataWork and Collector
 
         """
-        loop = asyncio.get_event_loop()
         if self.start == 0:
             print("Enviando msg inicial")
             self.init_datawork_data()
@@ -579,10 +538,10 @@ class DragonGather(TaskScheduler):
         """
         # input : ids, loop, sta
         uin = 3
-        idi=my_random_string(uin)
+        idi = my_random_string(uin)
         print("====Datawork Gather Iteration===")
-        bprint("idi %s, args %s"%(idi,args))
-        rprint("idi %s, kwargs %s" %(idi, kwargs))
+        bprint("idi %s, args %s" % (idi, args))
+        rprint("idi %s, kwargs %s" % (idi, kwargs))
         await asyncio.sleep(.5)
         loop = asyncio.get_event_loop()
         log = kwargs.get('log')
@@ -627,14 +586,14 @@ class DragonGather(TaskScheduler):
                 await rc.list_tables(rc.default_db)
                 origin = True
             except asyncio.TimeoutError as e:
-                idex=my_random_string(uin)
+                idex = my_random_string(uin)
                 log.exception(
                     "PD_TO1 IDEX %s: Tiempo fuera para conectar db source %s" % rc)
                 kwargs["origin_exception"] = "PD_TO1_00 + %s" % (idex, code)
                 self.rethinkdb_origin[ids] = False
                 rc.close()
                 del rc
-                rc=None
+                rc = None
                 return [ipt, ids, v,
                         [di, control, (rc, rc_enu),
                          process_data]], kwargs
@@ -647,27 +606,27 @@ class DragonGather(TaskScheduler):
             # rec_enu: destino
             rc_enu = self.add_sta_instance_destiny(ids, loop)
             try:
-                conn_enu = await rc_enu.async_connect()
+                await rc_enu.async_connect()
                 await rc_enu.list_dbs()
                 await rc_enu.select_db('enu_data')
                 table_name = self.stations[ids]['db']  # created on datawork
-                result_create = await rc_enu.create_table(table_name,
-                                                          rc_enu.default_db)
+                await rc_enu.create_table(table_name, rc_enu.default_db)
                 if 'DT_GEN' not in indexes:
                     await rc_enu.create_index(table_name, index='DT_GEN')
                 indexes = await rc_enu.get_indexes(table_name)
                 await rc_enu.list_tables(rc_enu.default_db)
                 destiny = True
             except asyncio.TimeoutError as e:
-                idex=my_random_string(uin)
+                idex = my_random_string(uin)
                 log.exception(
-                    "PD_TO2 IDEX %s: Tiempo fuera para conectar db destiny %s" % (idex, rc))
+                    '''PD_TO2 IDEX %s: Tiempo fuera para conectar
+                    db destiny %s''' % (idex, e))
                 kwargs["origin_exception"] = "PD_TO1_00 + %s" % code
                 self.rethinkdb_origin_enu[ids] = False
                 bprint(kwargs)
                 rc_enu.close()
                 del rc_enu
-                rc_enu=None
+                rc_enu = None
                 return [ipt, ids, v,
                         [di, control, (rc, rc_enu),
                          process_data]], kwargs
@@ -688,32 +647,34 @@ class DragonGather(TaskScheduler):
                                             key)
                 cursor = await shield(wait_for(future, timeout=30))
             except asyncio.TimeoutError as e:
-                idex=my_random_string(uin)
+                idex = my_random_string(uin)
                 log.exception(
-                    "PD_TO3 IDEX %s: Tiempo fuera para conectar db % s, al leer datos desde db, tabla %s" % (
-                        idex, rc, table_name))
+                    '''PD_TO3 IDEX %s: Tiempo fuera para conectar db % s,
+                    al leer datos desde db, tabla %s''' % (
+                        idex, e, table_name))
                 kwargs["origin_exception"] = "PD_TO3_00 + %s" % code
                 self.rethinkdb_origin[ids] = False
                 bprint(kwargs)
                 rc.close()
                 del rc
-                rc=None
-                log.exception("PD_TO3 IDEX %s: next iteration" % (idex, table_name))
+                rc = None
+                log.exception("PD_TO3 IDEX %s: next iteration" %
+                              (idex, table_name))
                 wargs = [ipt, ids, v, [
                     di, control, (rc, rc_enu), process_data]]
                 return wargs, kwargs
             except Exception as ex:
-                idex=my_random_string(uin)
+                idex = my_random_string(uin)
                 print("IDEX %s Exception" % idex, ex)
                 print("Error en obtención de data desde rethinkdb")
                 rc.logerror(
                     "IDEX = %s, Error en la obtención de datos para estación %s en %s" % (
-                        idex,code, di))
+                        idex, code, di))
                 kwargs["origin_exception"] = "PD_TO4_00 + %s" % code
                 self.rethinkdb_origin[ids] = False
                 rc.close()
                 del rc
-                rc=None
+                rc = None
                 wargs = [ipt, ids, v, [
                     di, control, (rc, rc_enu), process_data]]
                 return wargs, kwargs
@@ -758,7 +719,8 @@ class DragonGather(TaskScheduler):
                             self.dbus_geojson_queue.put(send)
                     except asyncio.TimeoutError as e:
                         log.exception(
-                            "PD_TO3: Tiempo fuera para conectar db %s, al leer datos desde db" % rc)
+                            f"PD_TO3: Tiempo fuera para conectar db {e}, al" +
+                            "leer datos desde db")
                         kwargs["origin_exception"] = "PD_TO5_01 + %s" % code
                         self.rethinkdb_origin_enu[ids] = False
                         rc_enu.close()
@@ -788,10 +750,13 @@ class DragonGather(TaskScheduler):
                 dt_recv = cursor[-1].get('DT_RECV')
                 di = cursor[-1].get('DT_GEN', dt_recv)
                 control = True
-            return [ipt, ids, v, [di, control, (rc, rc_enu), process_data]], kwargs
+            return [
+                ipt, ids, v,
+                [di, control, (rc, rc_enu), process_data]
+            ], kwargs
         return [ipt, ids, v, sta], kwargs
 
-    async def status_gather_task(self, ids, loop, wargs_list):
+    async def status_gather_task(self, ids, loop, wargs_list, **kwargs):
         # List of stations asigned to cpu
         # await asyncio.sleep(5)
 
@@ -800,29 +765,34 @@ class DragonGather(TaskScheduler):
 
         task_result = {}
 
+        bprint("Check on status task if assigned")
+        value = self.status_tasks[ids]
+        rprint(f"IDS {ids} -> {value}")
         if self.status_tasks[ids]:
             try:
                 wargs = [ids, loop, wargs_list]
-                result = await self.gather_data(*wargs)
+                result, kwargs = await self.gather_data(
+                    *wargs, **kwargs)
                 task_result.update({ids: result[2]})
                 wargs = result[2]
                 wargs_list = wargs
                 self.status_tasks[ids] = True
             except Exception as e:
                 raise e
-        return [ids, loop, wargs_list]
+        return [ids, loop, wargs_list], kwargs
 
-    async def gather_process(self, ipt, loop, ipt_wargs_dict):
+    async def gather_process(self, ipt, loop, ipt_wargs_dict, **kwargs):
         result_dict = {}
         ids_list = self.proc_tasks[ipt]
         for ids in ids_list:
-            if not ids in ipt_wargs_dict.keys():
+            if ids not in ipt_wargs_dict.keys():
                 wargs = [None, None, None, None]
                 ipt_wargs_dict.update({ids: wargs})
             wargs_dict = [ids, loop, ipt_wargs_dict[ids]]
-            result = await self.status_gather_task(*wargs_dict)
+            result, kwargs = await self.status_gather_task(
+                *wargs_dict, **kwargs)
             result_dict.update({ids: result[2]})
-        return [ipt, loop, result_dict]
+        return [ipt, loop, result_dict], kwargs
 
     def set_pst(self, ids, args, kwargs):
         return [args[0], ids, *args[1:]], kwargs
@@ -832,6 +802,7 @@ class DragonGather(TaskScheduler):
         This definition is for collector instance
         """
         log = FileLog("Gather@Datawork", "CORE_%s" %
-                      ipt, "localhost@pineiden", path=self.log_path/"engine")
+                      ipt, "localhost@pineiden",
+                      path=self.log_path/"engine")
         self.log_manager[ipt] = log
         return [ipt, 1, (None, None, (None, None), None)], {"log": log}
